@@ -1,5 +1,5 @@
 arma.spec <-
-function(ar=0,ma=0,var.noise=1,n.freq=500,  ...)
+function(ar=0, ma=0, var.noise=1, n.freq=500, log='n', ...)
 { 
      plot = graphics::plot     
 	 check <- 0
@@ -17,7 +17,7 @@ function(ar=0,ma=0,var.noise=1,n.freq=500,  ...)
     ma.order <- length(ma) 
     # check (near) parameter redundancy [i.e. are any roots (approximately) equal]  
        for (i in 1:ar.order) {
-       if ( (ar == 0 & ar.order == 1) || (ma == 0 & ma.order ==1) ) break
+       if ( (ar[1] == 0 && ar.order == 1) || (ma[1] == 0 && ma.order ==1) )  break
        if(any(abs(z.ar[i]-z.ma[1:ma.order]) < 1e-03)) {cat("WARNING: Parameter Redundancy", "\n"); break}
        }
     #
@@ -29,7 +29,7 @@ function(ar=0,ma=0,var.noise=1,n.freq=500,  ...)
     spec <- var.noise*((1 - cs.ma)^2 + sn.ma^2)/((1 - cs.ar)^2 + sn.ar^2)
     spg.out <- list(freq=freq, spec=spec)
     class(spg.out) <- "spec"
-    plot(spg.out, ci=0, ...)
+    plot(spg.out, ci=0, panel.first=Grid(), log = log, ...)
     return(invisible(spg.out))
 }
 
